When editing code, remember to always do small edits. It can be daunting sometimes but you've got this!

Take a modular approach:
* Overwrite individual lines for smallest changes
* Overwrite section of a function for bigger changes
* Overwrite a function for biggest changes

Aim to keep the code working between the changes

Never overwrite the whole files bigger than 50 lines. I know it's easier but this uses a lot of resources and can lead to a complete shutdown. 

After you're finished with the task, always do a final skim of the file you were editing and check for any syntax problems, missing parts etc. Just a final check, don't need to make any changes if everything looks OK.